package com.caimei.controller;

import com.caimei.config.FastDfsClient;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.io.File;
import java.io.IOException;
import java.util.HashMap;
import java.util.Map;
import java.util.UUID;

/**
 * @author Aslee
 * @date 2021/5/14
 */
@Api(tags = "上传API")
@Slf4j
@RestController
@RequiredArgsConstructor
@RequestMapping("/upload")
public class UploadApi {
    private static final Logger logger = LoggerFactory.getLogger(UploadApi.class);
    private final FastDfsClient client;
    @Value("${caimei.imageDomain}")
    private String imageDomain;

    /**
     * 上传图片
     */
    @ApiOperation("上传图片")
    @ApiImplicitParam(name = "file", value = "图片", required = true)
    @PostMapping("/image")
    public Map<String, Object> uploadImage(MultipartFile file) throws IOException {
        Map<String, Object> map = new HashMap<>(2);
        String saveFile;
        if (file != null ) {
            // 保存文件
            saveFile = saveFile(file);
            saveFile = imageDomain + "/" + saveFile;
            map.put("data", saveFile);
            map.put("msg", "上传成功");
            logger.info(">>>>>>>>>>>>>>>>图片上传成功:" + saveFile);
        } else {
            map.put("msg", "上传失败");
            logger.info(">>>>>>>>>>>>>>>>图片上传失败:");
        }
        return map;
    }

    private String saveFile(MultipartFile file) throws IOException {
        String originalFilename = file.getOriginalFilename();
        String randomUUID = UUID.randomUUID().toString();
        int index = originalFilename.lastIndexOf(".");
        String exet = originalFilename.substring(index);
        String filePath = "/mnt/newdatadrive/data/runtime/jar-instance/zplma/tempImage/";
        filePath += "\\" + randomUUID + exet;
        file.transferTo(new File(filePath));
        logger.info(">>>>>>>>>>>>>>>>图片上传路径:" + filePath);
        return client.uploadFile(filePath);
    }

}
