package com.caimei.service;

import com.caimei.model.ResponseJson;
import com.caimei.model.vo.AuthVo;
import com.caimei.model.vo.BrandVo;
import com.github.pagehelper.PageInfo;

import java.util.List;

/**
 * Description
 *
 * @author : Aslee
 * @date : 2021/5/11
 */
public interface AuthService {

    /**
     * 授权列表
     * @param authUserId    供应商用户id
     * @param authParty     授权机构
     * @param pageNum       第几页
     * @param pageSize      一页多少条
     * @return  AuthVo
     */
    ResponseJson<PageInfo<AuthVo>> getAuthList(Integer authUserId, String authParty, Integer pageNum, Integer pageSize);

    /**
     * 更新授权状态
     * @param authId    授权id
     * @param status    授权状态:0停用 1启用
     * @return  ResponseJson
     */
    ResponseJson updateAuthStatus(Integer authId, Integer status);

    /**
     * 删除授权
     * @param authId    授权id
     * @return  ResponseJson
     */
    ResponseJson deleteAuth(Integer authId);

    /**
     * 添加/编辑授权
     *
     * @param authId            授权id
     * @param authUserId        供应商用户id
     * @param authParty         授权机构
     * @param status            授权状态：0已下架 1已上架
     * @param createBy          创建人id
     * @return  ResponseJson
     */
    ResponseJson saveAuth(Integer authId, Integer authUserId, String authParty, Integer status, Integer createBy);
}
