package com.caimei.service.impl;

import com.caimei.mapper.AuthMapper;
import com.caimei.model.ResponseJson;
import com.caimei.model.po.CmBrandAuthPo;
import com.caimei.model.vo.AuthVo;
import com.caimei.model.vo.BrandVo;
import com.caimei.service.AuthProductService;
import com.caimei.service.AuthService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;

/**
 * Description
 *
 * @author : Aslee
 * @date : 2021/5/11
 */
@Slf4j
@Service
public class AuthServiceImpl implements AuthService {

    @Resource
    private AuthMapper authMapper;

    private AuthProductService authProductService;

    @Autowired
    public void setAuthProductService(AuthProductService authProductService) {
        this.authProductService = authProductService;
    }

    @Override
    public ResponseJson<PageInfo<AuthVo>> getAuthList(Integer authUserId, String authParty, Integer pageNum, Integer pageSize) {
        if (null == authUserId) {
            return ResponseJson.error("参数异常，请输入供应商用户id", null);
        }
        PageHelper.startPage(pageNum, pageSize);
        List<AuthVo> authList = authMapper.getAuthList(authUserId, authParty);
        PageInfo<AuthVo> pageData = new PageInfo<>(authList);
        return ResponseJson.success(pageData);
    }

    @Override
    public ResponseJson updateAuthStatus(Integer authId, Integer status) {
        if (authId == null) {
            return ResponseJson.error("请输入用户id");
        }
        if (status == null) {
            return ResponseJson.error("请输入要更新的状态值");
        } else if (status != 0 && status != 1) {
            return ResponseJson.error("状态值只能为0或1");
        }
        authMapper.updateAuthStatusByAuthId(authId, status);
        if (status == 0) {
            return ResponseJson.success("下线品牌授权成功");
        } else {
            return ResponseJson.success("上线品牌授权成功");
        }
    }

    @Override
    public ResponseJson deleteAuth(Integer authId) {
        if (null == authId) {
            return ResponseJson.error("参数异常，请输入授权id");
        }
        // 删除品牌授权
        authMapper.deleteAuthByAuthId(authId);
        // 删除商品及商品参数
        List<Integer> productIdList = authProductService.getProductIdsByAuthId(authId);
        productIdList.forEach(productId->{
            if (null != productId) {
                authProductService.deleteProduct(productId);
            }
        });
        return ResponseJson.success("删除品牌授权成功");
    }

    @Override
    public ResponseJson saveAuth(Integer authId, Integer authUserId, String authParty, Integer status, Integer createBy) {
        if (null == authUserId) {
            return ResponseJson.error("参数异常，请输入供应商用户id");
        }
        if (StringUtils.isBlank(authParty)) {
            return ResponseJson.error("参数异常，请输入授权机构名称");
        }
        if (null == status) {
            return ResponseJson.error("参数异常，请输入授权状态值");
        } else if (status != 0 && status != 1) {
            return ResponseJson.error("参数异常，授权状态值只能为0或1");
        }
        if (null == createBy) {
            return ResponseJson.error("参数异常，请输入创建人id");
        }
        /*
            组装授权数据
         */
        CmBrandAuthPo auth = new CmBrandAuthPo();
        auth.setAuthUserId(authUserId);
        auth.setAuthParty(authParty);
        auth.setStatus(status);
        if (null == authId) {
            auth.setCreateBy(createBy);
            auth.setCreateTime(new Date());
        } else {
            auth.setId(authId);
        }
        /*
            保存授权
         */
            if (null == authId) {
                authMapper.insertAuth(auth);
            } else {
                authMapper.updateAuthByAuthId(auth);
            }
        return ResponseJson.success("保存品牌授权成功");
    }
}
